==> huaweicloudsdkddm-3.0.61-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/create_database_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateDatabaseResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'databases': 'list[CreateDatabaseDetailResponses]'
    }

    attribute_map = {
        'databases': 'databases'
    }

    def __init__(self, databases=None):
        """CreateDatabaseResponse - a model defined in huaweicloud sdk"""
        
        super(CreateDatabaseResponse, self).__init__()

        self._databases = None
        self.discriminator = None

        if databases is not None:
            self.databases = databases

    @property
    def databases(self):
        """Gets the databases of this CreateDatabaseResponse.

        逻辑库相关信息的集合。

        :return: The databases of this CreateDatabaseResponse.
        :rtype: list[CreateDatabaseDetailResponses]
        """
        return self._databases

    @databases.setter
    def databases(self, databases):
        """Sets the databases of this CreateDatabaseResponse.

        逻辑库相关信息的集合。

        :param databases: The databases of this CreateDatabaseResponse.
        :type: list[CreateDatabaseDetailResponses]
        """
        self._databases = databases

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDatabaseResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkddm-3.1.9-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/create_database_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateDatabaseResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'databases': 'list[CreateDatabaseDetailResponses]'
    }

    attribute_map = {
        'databases': 'databases'
    }

    def __init__(self, databases=None):
        """CreateDatabaseResponse

        The model defined in huaweicloud sdk

        :param databases: 逻辑库相关信息的集合。
        :type databases: list[:class:`huaweicloudsdkddm.v1.CreateDatabaseDetailResponses`]
        """
        
        super(CreateDatabaseResponse, self).__init__()

        self._databases = None
        self.discriminator = None

        if databases is not None:
            self.databases = databases

    @property
    def databases(self):
        """Gets the databases of this CreateDatabaseResponse.

        逻辑库相关信息的集合。

        :return: The databases of this CreateDatabaseResponse.
        :rtype: list[:class:`huaweicloudsdkddm.v1.CreateDatabaseDetailResponses`]
        """
        return self._databases

    @databases.setter
    def databases(self, databases):
        """Sets the databases of this CreateDatabaseResponse.

        逻辑库相关信息的集合。

        :param databases: The databases of this CreateDatabaseResponse.
        :type databases: list[:class:`huaweicloudsdkddm.v1.CreateDatabaseDetailResponses`]
        """
        self._databases = databases

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDatabaseResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
